.. image:: https://travis-ci.org/musevlt/muse-psfr.svg?branch=master
  :target: https://travis-ci.org/musevlt/muse-psfr

.. image:: https://codecov.io/gh/musevlt/muse-psfr/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/musevlt/muse-psfr

The MUSE-PSFR code allows to reconstruct a PSF for the `MUSE WFM-AO
<https://www.eso.org/sci/facilities/paranal/instruments/muse/inst.html>`_ mode,
using telemetry data from `SPARTA
<https://www.eso.org/sci/facilities/develop/ao/tecno/sparta.html>`_.

The method will be presented in more details in a forthcoming publication
([Fusco et al. in prep.]).

Links:

- `Documentation <https://muse-psfr.readthedocs.io/>`_
- `PyPI <https://pypi.org/project/muse-psfr/>`_
- `Github <https://github.com/musevlt/muse-psfr>`_
